@@ -28,7 +28,7 @@ enum CostumeAction
 pub struct CostumeDocument
 {
     action_history : ActionHistory,
-    data_id : DataId,
+    data_id : DataId<Costume>,
     show_origin : bool,
     transparent_color : [f32; 3],
     zoom_level : f32,
@@ -158,7 +158,7 @@ impl CostumeDocument
                 {
                     let new_cel = AnimationCel
                     {
-                        sheet : DataHandle::new(&package_name, &sheet_name),
+                        sheet : DataHandle::with_path(&package_name, &sheet_name),
                         slice : SliceHandle::new(&slice_name),
                         delay : delay as f64,
                         x : offset[0],
@@ -369,7 +369,7 @@ impl CostumeDocument
                     {
                         ui.menu(&sheet_name, ||
                         {
-                            let sheet_id = sheet_store.get_id(package, sheet_name).unwrap_or(0);
+                            let sheet_id = sheet_store.get_id(package, sheet_name).unwrap_or(DataId::new(0));
 
                             if let Some(sheet) = sheet_store.get(sheet_id)
                             {
@@ -381,7 +381,7 @@ impl CostumeDocument
                                         {
                                             let mut cel = AnimationCel::new();
 
-                                            cel.sheet = DataHandle::new(package, sheet_name);
+                                            cel.sheet = DataHandle::with_path(package, sheet_name);
                                             cel.slice = SliceHandle::new(&slice_name);
 
                                             self.queue_action(Box::new(CostumeAction::AddCel(self.current_animation, self.current_cel, cel)));
@@ -429,7 +429,7 @@ impl Document for CostumeDocument
 {
     fn load(game: &mut GameControl, package_name: &str, item_name: &str) -> Self where Self: Sized
     {
-        let mut data_id = 0;
+        let mut data_id = DataId::new(0);
 
         if let Ok(id) = game.res().store_mut::<Costume>().get_id_mut(package_name, item_name)
         {
