@@ -29,7 +29,7 @@ enum SheetAction
 pub struct SheetDocument
 {
     action_history : ActionHistory,
-    data_id : DataId,
+    data_id : DataId<Sheet>,
     show_origin : bool,
     transparent_color : [f32; 3],
     zoom_level : f32,
@@ -671,7 +671,7 @@ impl SheetDocument
                 }
 
                 ui.same_line_with_pos(1.0);
-                imgui::Image::new(imgui::TextureId::from(self.data_id), [width, height]).build(ui);
+                imgui::Image::new(imgui::TextureId::from(self.data_id.index()), [width, height]).build(ui);
 
                 if !self.on_tilegen
                 {
@@ -754,7 +754,7 @@ impl SheetDocument
 
                 ui.set_cursor_pos([image_x, image_y]);
 
-                imgui::Image::new(imgui::TextureId::from(self.data_id), [slice.texture_w * self.zoom_level, slice.texture_h * self.zoom_level])
+                imgui::Image::new(imgui::TextureId::from(self.data_id.index()), [slice.texture_w * self.zoom_level, slice.texture_h * self.zoom_level])
                     .uv0([x1, y1]).uv1([x2, y2]).build(ui);
 
                 ui.set_cursor_pos([center_x, center_y]);
@@ -782,7 +782,7 @@ impl Document for SheetDocument
 {
     fn load(game : &mut GameControl, package_name : &str, item_name: &str) -> Self where Self : Sized
     {
-        let mut data_id = 0;
+        let mut data_id = DataId::new(0);
 
         if let Ok(id) = game.res().store_mut::<Sheet>().get_id_mut(package_name, item_name)
         {
