@@ -22,7 +22,7 @@ enum SpawnableSetAction
 pub struct SpawnableSetDocument
 {
     action_history : ActionHistory,
-    data_id : DataId,
+    data_id : DataId<SpawnableSet>,
     current_spawnable : usize,
     scroll_spawn_list : bool,
     focus_spawnable_name_input : bool,
@@ -170,7 +170,7 @@ impl SpawnableSetDocument
 
                         spawnable_clone.set_representation(Representation::Actor
                         {
-                            costume: DataHandle::new(&package_name, &costume_name)
+                            costume: DataHandle::with_path(&package_name, &costume_name)
                         });
 
                         self.queue_action(Box::new(SpawnableSetAction::SetSpawnable(self.current_spawnable, spawnable_clone)));
@@ -194,7 +194,9 @@ impl SpawnableSetDocument
         }
     }
 
-    fn spawnable_list_view(&mut self, ui : &imgui::Ui, spawnables : &mut SpawnableSet)
+    fn spawnable_list_view(&mut self, ui : &imgui::Ui, spawnables : &mut SpawnableSet,
+                           costume_store : &mut DataStore<Costume>, sheet_store : &mut DataStore<Sheet>,
+                           packages : &mut Packages)
     {
         let main_style = ui.clone_style();
 
@@ -225,45 +227,7 @@ impl SpawnableSetDocument
 
         if let Some(spawnable_list) = imgui::ChildWindow::new("spawnable_list").border(true).draw_background(true).begin(ui)
         {
-            let num_spawnables = spawnables.spawnable_count();
-
-            for i in 0..num_spawnables
-            {
-                let spawnable_name;
-                let mut icon = "";
-
-                if let Some(spawnable) = spawnables.spawnable(i)
-                {
-                    icon = crate::util::representation_icon(spawnable.representation());
-                }
-
-                let height = crate::util::height_with_icon(ui);
-
-                if imgui::Selectable::new(format!("##spawnable {}", i)).size([0.0, height]).selected(self.current_spawnable == i).build(ui)
-                {
-                    self.current_spawnable = i;
-                }
-
-                if let Some(name) = spawnables.spawnable_name(i)
-                {
-                    spawnable_name = name;
-                }
-                else
-                {
-                    spawnable_name = format!("<spawnable {}>", i);
-                }
-
-                let old_cursor = ui.cursor_pos();
-                ui.same_line();
-                crate::util::icon_label(icon, &spawnable_name, ui);
-                ui.set_cursor_pos(old_cursor);
-
-                if self.current_spawnable == i && self.scroll_spawn_list
-                {
-                    ui.set_scroll_here_y();
-                    self.scroll_spawn_list = false;
-                }
-            }
+            crate::util::ui_spawnable_list(spawnables, &mut self.current_spawnable, &mut self.scroll_spawn_list, costume_store, sheet_store, packages, ui);
 
             spawnable_list.end();
         }
@@ -311,7 +275,7 @@ impl Document for SpawnableSetDocument
 {
     fn load(game : &mut GameControl, package_name : &str, item_name : &str) -> Self where Self : Sized
     {
-        let mut data_id = 0;
+        let mut data_id = DataId::new(0);
 
         if let Ok(id) = game.res().store_mut::<SpawnableSet>().get_id_mut(package_name, item_name)
         {
@@ -372,7 +336,7 @@ impl Document for SpawnableSetDocument
 
                 if let Some(spawnable_list_view) = imgui::ChildWindow::new("spawnable_list_view").size([0.0, 0.0]).movable(false).begin(ui)
                 {
-                    self.spawnable_list_view(ui, spawnables);
+                    self.spawnable_list_view(ui, spawnables, &mut costume_store, &mut sheet_store, packages);
 
                     spawnable_list_view.end();
                 }
