@@ -28,7 +28,7 @@ enum TilesetAction
 pub struct TilesetDocument
 {
     action_history : ActionHistory,
-    data_id : DataId,
+    data_id : DataId<Tileset>,
     current_tile : usize,
     extra_selection : HashSet<usize>,
     left_column_set : bool,
@@ -767,7 +767,7 @@ impl Document for TilesetDocument
 {
     fn load(game : &mut GameControl, package_name : &str, item_name : &str) -> Self where Self : Sized
     {
-        let mut data_id = 0;
+        let mut data_id = DataId::new(0);
 
         if let Ok(id) = game.res().store_mut::<Tileset>().get_id_mut(package_name, item_name)
         {
@@ -806,7 +806,7 @@ impl Document for TilesetDocument
                 {
                     TilesetAction::SetSheet(package, name) =>
                     {
-                        tileset.set_sheet(DataHandle::new(&package, &name));
+                        tileset.set_sheet(DataHandle::with_path(&package, &name));
                         return true;
                     },
                     TilesetAction::SetTileSize(width, height) =>
@@ -892,10 +892,10 @@ impl Document for TilesetDocument
             let source = tileset.sheet();
             let sheet_opt = match sheet_store.get_id(source.package(), source.path())
             {
-                Ok(index) =>
+                Ok(id) =>
                 {
-                    texture_id = index;
-                    sheet_store.get(index)
+                    texture_id = id.index();
+                    sheet_store.get(id)
                 }
                 Err(_) =>
                 {
