@@ -17,7 +17,6 @@ use keeshond_treats::world::Level;
 use std::collections::{HashMap, HashSet};
 use std::string::ToString;
 use std::slice::{Iter};
-use std::time::Instant;
 
 use imgui::StyleColor;
 
@@ -539,16 +538,12 @@ impl Packages
             for package_name in res.packages_to_load.iter()
             {
                 let mut contents = Vec::new();
-                let load_start = Instant::now();
 
                 match res_type.load_package(game, package_name)
                 {
                     Ok(_) =>
                     {
-                        let load_time = (Instant::now() - load_start).as_millis();
                         contents = res_type.list_package_contents(game, &package_name);
-
-                        info!("Loaded {} package \"{}\" in {} ms", res_type.folder_name(), &package_name, load_time);
                     },
                     Err(error) =>
                     {
@@ -1224,13 +1219,9 @@ impl EditorGui
 
         if editor.queue_auto_import >= AUTO_IMPORT_DIALOG_DELAY
         {
-            match editor.auto_import.import_pending(&mut editor.packages, game)
+            if editor.auto_import.import_pending(&mut editor.packages, game) == ImportPendingResult::NeedsConfig
             {
-                ImportPendingResult::Ok => {}
-                ImportPendingResult::NeedsConfig =>
-                {
-                    self.auto_import_open = true;
-                }
+                self.auto_import_open = true;
             }
             editor.queue_auto_import = 0;
         }
