@@ -194,6 +194,7 @@ pub struct ImportGroupItem<T>
     data : T
 }
 
+#[derive(Eq, PartialEq)]
 pub enum ImportPendingResult
 {
     Ok,
@@ -675,7 +676,7 @@ impl AutoImport
                 {
                     animation.add_cel(AnimationCel
                     {
-                        sheet : DataHandle::new(&package, &name),
+                        sheet : DataHandle::with_path(&package, &name),
                         slice : SliceHandle::new(&format!("{}{}", prefix, frame.index)),
                         delay : frame.delay,
                         x : 0.0,
@@ -701,8 +702,8 @@ impl AutoImport
                 let mut spawnable = Spawnable::new();
                 spawnable.set_representation(Representation::Actor
                 {
-                    costume : DataHandle::new(&item.data.dest_costume_package,
-                                              &item.data.dest_costume)
+                    costume : DataHandle::with_path(&item.data.dest_costume_package,
+                                                    &item.data.dest_costume)
                 });
 
                 new_spawnables.add_spawnable(spawnable);
