@@ -11,7 +11,7 @@ use num::Float;
 use toodee::TooDeeOps;
 
 use keeshond_treats::tilemap::{Tilemap, Tileset};
-use keeshond_treats::spawnable::Representation;
+use keeshond_treats::spawnable::{Representation, Spawnable, SpawnableSet};
 use log::Level;
 
 pub const ICON_PACKAGE : &'static str = "a";
@@ -51,6 +51,7 @@ pub const ICON_LOCKED : &'static str = "H";
 #[allow(dead_code)] pub const ICON_UNLOCKED : &'static str = "I";
 
 pub const ICON_FONT_SIZE : f32 = 16.0;
+pub const REPRESENTATION_ICON_SIZE : f32 = 32.0;
 
 pub const REPRESENTATION_NAMES : [&'static str; 3] = ["None", "Actor", "Tilemap"];
 
@@ -59,7 +60,7 @@ const PASCAL_DISALLOWED_CHARS : [char; 33] = [' ', '!', '"', '#', '$', '%', '&',
     '>', '?', '@', '[', '\\', ']', '^', '_', '`', '{',
     '|', '}', '~'];
 
-pub fn representation_icon(representation : &Representation) -> &'static str
+pub fn representation_font_icon(representation : &Representation) -> &'static str
 {
     match representation
     {
@@ -287,11 +288,77 @@ pub fn icon_label(icon : &str, name : &str, ui : &imgui::Ui)
     ui.text(name);
 }
 
-pub fn height_with_icon(ui : &imgui::Ui) -> f32
+pub fn representation_icon_label(spawnable_opt : Option<&Spawnable>, name : &str, costume_store : &DataStore<Costume>,
+                                 sheet_store : &DataStore<Sheet>, packages : &mut Packages, ui : &imgui::Ui)
 {
-    let size = ui.calc_text_size("");
+    let old_cursor = ui.cursor_pos();
+    let height = ui.current_font().font_size;
 
-    size[1].max(15.0)
+    ui.set_cursor_pos([old_cursor[0], old_cursor[1]]);
+
+    if let Some(spawnable) = spawnable_opt
+    {
+        representation_icon(spawnable, costume_store, sheet_store, packages, ui);
+    }
+
+    ui.same_line();
+    ui.set_cursor_pos([old_cursor[0] + REPRESENTATION_ICON_SIZE + 8.0, old_cursor[1] + ((REPRESENTATION_ICON_SIZE - height) / 2.0)]);
+    ui.text(name);
+}
+
+pub fn representation_icon(spawnable : &Spawnable, costume_store : &DataStore<Costume>,
+                           sheet_store : &DataStore<Sheet>, packages : &mut Packages, ui : &imgui::Ui)
+{
+    let (icon_min, icon_max) = (ui.item_rect_min(), ui.item_rect_max());
+    let mut using_image = false;
+
+    if ui.is_rect_visible(icon_min, icon_max)
+    {
+        match spawnable.representation()
+        {
+            Representation::Actor { costume } =>
+            {
+                if let Some((mut image, rect)) = costume_image(costume, costume_store, sheet_store, packages)
+                {
+                    let fit = box_fit(rect.w, rect.h, REPRESENTATION_ICON_SIZE, REPRESENTATION_ICON_SIZE);
+                    let cursor_pos = ui.cursor_pos();
+                    ui.set_cursor_pos([cursor_pos[0] + fit.x, cursor_pos[1] + fit.y]);
+
+                    image = image.size([fit.width, fit.height]);
+                    image.build(ui);
+                    using_image = true;
+                }
+            }
+            _ => {}
+        }
+
+        if !using_image
+        {
+            let draw_list = ui.get_window_draw_list();
+            let old_cursor = ui.cursor_pos();
+            let screen_cursor = ui.cursor_screen_pos();
+
+            let style = ui.clone_style();
+            let outside_color = style.colors[imgui::StyleColor::Button as usize];
+            let start = [screen_cursor[0], screen_cursor[1]];
+            let end = [screen_cursor[0] + REPRESENTATION_ICON_SIZE, screen_cursor[1] + REPRESENTATION_ICON_SIZE];
+
+            draw_list.add_rect(start, end, outside_color).filled(true).rounding(2.0).build();
+            draw_list.add_rect(start, end, outside_color).filled(false).thickness(1.0).rounding(2.0).build();
+
+            let icon = representation_font_icon(spawnable.representation());
+            let icon_font = get_icon_font(ui);
+            let font = ui.push_font(icon_font);
+            let icon_size = ui.calc_text_size(icon);
+
+            ui.set_cursor_pos([old_cursor[0] + ((REPRESENTATION_ICON_SIZE - icon_size[0]) / 2.0),
+                old_cursor[1] + ((REPRESENTATION_ICON_SIZE - icon_size[1]) / 2.0)]);
+
+            ui.text(icon);
+
+            font.pop();
+        }
+    }
 }
 
 pub fn data_path_edit(ui : &imgui::Ui, label : &str, package : &mut String, name : &mut String) -> bool
@@ -311,6 +378,47 @@ pub fn data_path_edit(ui : &imgui::Ui, label : &str, package : &mut String, name
     changed
 }
 
+pub fn ui_spawnable_list(spawnables : &SpawnableSet, index : &mut usize, scroll : &mut bool,
+                         costume_store : &DataStore<Costume>, sheet_store : &DataStore<Sheet>,
+                         packages : &mut Packages, ui : &imgui::Ui) -> bool
+{
+    let mut activated = false;
+    let num_spawnables = spawnables.spawnable_count();
+
+    for i in 0..num_spawnables
+    {
+        let spawnable_name;
+
+        if imgui::Selectable::new(format!("##spawnable {}", i)).size([0.0, REPRESENTATION_ICON_SIZE]).selected(*index == i).build(ui)
+        {
+            *index = i;
+            activated = true;
+        }
+
+        if let Some(name) = spawnables.spawnable_name(i)
+        {
+            spawnable_name = name;
+        }
+        else
+        {
+            spawnable_name = format!("<spawnable {}>", i);
+        }
+
+        let old_cursor = ui.cursor_pos();
+        ui.same_line();
+        crate::util::representation_icon_label(spawnables.spawnable(i), &spawnable_name, costume_store, sheet_store, packages, ui);
+        ui.set_cursor_pos(old_cursor);
+
+        if *index == i && *scroll
+        {
+            ui.set_scroll_here_y();
+            *scroll = false;
+        }
+    }
+
+    activated
+}
+
 pub fn name_to_pascal_case(name : &str) -> String
 {
     let parts : Vec<String> = name.split(&PASCAL_DISALLOWED_CHARS[..]).map(|part| part.to_string()).collect();
@@ -351,7 +459,7 @@ pub fn tile_size(tilemap : &Tilemap, tileset_store : &DataStore<Tileset>) -> (f6
     (tile_w, tile_h)
 }
 
-pub fn cel_image(cel : &AnimationCel, sheet_store : &mut DataStore<Sheet>, packages : &mut Packages) -> Option<(imgui::Image, Rect<f32>)>
+pub fn cel_image(cel : &AnimationCel, sheet_store : &DataStore<Sheet>, packages : &mut Packages) -> Option<(imgui::Image, Rect<f32>)>
 {
     let (package, sheet_name) = (cel.sheet.package(), cel.sheet.path());
 
@@ -371,7 +479,7 @@ pub fn cel_image(cel : &AnimationCel, sheet_store : &mut DataStore<Sheet>, packa
                     let (w, h) = (slice.texture_w, slice.texture_h);
                     let rect = crate::util::slice_to_uv(sheet, slice);
 
-                    return Some((imgui::Image::new(imgui::TextureId::from(sheet_id), [w, h])
+                    return Some((imgui::Image::new(imgui::TextureId::from(sheet_id.index()), [w, h])
                         .uv0([rect.x1, rect.y1]).uv1([rect.x2, rect.y2]), Rect
                     {
                         x : slice.origin_x, y : slice.origin_y, w, h
@@ -388,7 +496,7 @@ pub fn cel_image(cel : &AnimationCel, sheet_store : &mut DataStore<Sheet>, packa
     None
 }
 
-pub fn cel_sheet_slice(cel : &AnimationCel, sheet_store : &mut DataStore<Sheet>, packages : &mut Packages) -> Option<(DataId, usize)>
+pub fn cel_sheet_slice(cel : &AnimationCel, sheet_store : &mut DataStore<Sheet>, packages : &mut Packages) -> Option<(DataId<Sheet>, usize)>
 {
     let (package, sheet_name) = (cel.sheet.package(), cel.sheet.path());
 
@@ -429,8 +537,8 @@ pub fn cel_image_fit(cel : &AnimationCel, width : f32, height : f32,
     None
 }
 
-pub fn costume_image(costume : &DataHandle<Costume>, costume_store : &mut DataStore<Costume>,
-                     sheet_store : &mut DataStore<Sheet>, packages : &mut Packages) -> Option<(imgui::Image, Rect<f32>)>
+pub fn costume_image(costume : &DataHandle<Costume>, costume_store : &DataStore<Costume>,
+                     sheet_store : &DataStore<Sheet>, packages : &mut Packages) -> Option<(imgui::Image, Rect<f32>)>
 {
     if costume_store.package_loaded(costume.package())
     {
@@ -456,7 +564,7 @@ pub fn costume_image(costume : &DataHandle<Costume>, costume_store : &mut DataSt
 }
 
 pub fn costume_sheet_slice(costume : &DataHandle<Costume>, costume_store : &mut DataStore<Costume>,
-                     sheet_store : &mut DataStore<Sheet>, packages : &mut Packages) -> Option<(DataId, usize)>
+                     sheet_store : &mut DataStore<Sheet>, packages : &mut Packages) -> Option<(DataId<Sheet>, usize)>
 {
     if costume_store.package_loaded(costume.package())
     {
@@ -536,7 +644,7 @@ pub fn tile_drawable_item(tileset : &DataHandle<Tileset>, tile_index : u32, tile
                                 tile_w : tile_w as f32,
                                 tile_h : tile_h as f32,
                                 sheet_id,
-                                shader_id : 0,
+                                shader_id : DataId::new(0),
                                 r : 1.0,
                                 g : 1.0,
                                 b : 1.0,
@@ -576,7 +684,7 @@ pub fn tilemap_drawable_item(tilemap : &Tilemap, rect : BakedRect<f64>, tileset_
 
                     if let Some(sheet) = sheet_store.get(sheet_id)
                     {
-                        tilemap.update_sprite_layout(tileset, sheet, &mut sprite, rect);
+                        tilemap.grid().update_sprite_layout(tileset, sheet, &mut sprite, rect);
 
                         return DrawableItem::MultiTileSprite(sprite);
                     }
